@@ -7,7 +7,7 @@
 
 #include "mew.h"
 
-private char version_message[] = "version 5.2 20060727 Yasunari Momoi";
+private char version_message[] = "version 6.6 20140416 Yasunari Momoi";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -158,9 +158,7 @@ Gethomedir(void)
 #ifdef HAVE_GETPWUID
 	{
 		struct passwd *pw;
-		if ((pw = getpwuid(getuid())) == NULL)
-			return NULL;
-		else
+		if ((pw = getpwuid(getuid())) != NULL)
 			return pw->pw_dir;
 	}
 #endif
@@ -627,7 +625,7 @@ lock_mbox(char *lockfile)
 	int retry = 5;
 
 	while (TRUE) {
-		if ((fd = open(lockfile, O_WRONLY | O_CREAT | O_EXCL)) < 0) {
+	  if ((fd = open(lockfile, O_WRONLY | O_CREAT | O_EXCL, 0666)) < 0) {
 			if (errno == EACCES || errno == EROFS)
 				return 1; /* doesn't need a lockfile, maybe. */
 			else if (errno != EEXIST)
