@@ -9,7 +9,7 @@
 
 #include "mew.h"
 
-private char version_message[] = "version 5.3 20060727 Kazu Yamamoto";
+private char version_message[] = "version 6.6 20140416 Kazu Yamamoto";
 
 #ifdef HAVE_UNISTD_H
 # include <sys/types.h>
@@ -348,7 +348,7 @@ nextfield(char *p, char *lim, char **truncated_end, char **prev_beg, int hdr_onl
 	do {
 		q = p;
 		p = nextline(p, lim, hdr_only);
-		if (p == NULL) return NULL;
+		if (p == NULL) break;
 		i++;
 		if (Field_len != 0 && i == Field_len)
 			*truncated_end = p;
