@@ -36,6 +36,8 @@
   (setq buffer-read-only t)
   (setq truncate-lines t)
   ;;
+  (if (boundp 'bidi-paragraph-direction)
+      (setq bidi-paragraph-direction 'left-to-right))
   (make-local-variable 'tab-width)
   (make-local-variable 'search-invisible)
   (setq search-invisible nil)
@@ -212,7 +214,7 @@ If called with '\\[universal-argument]', you can specify a target mark."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2012 Mew developing team.
+;; Copyright (C) 1996-2015 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
